@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2018-2020 Alexander Borisov
+ * Copyright (C) 2018-2023 Alexander Borisov
  *
  * Author: Alexander Borisov <borisov@lexbor.com>
  */
@@ -8,6 +8,9 @@
 #define LEXBOR_BASE_H
 
 #ifdef __cplusplus
+#define __STDC_LIMIT_MACROS
+#define __STDC_CONSTANT_MACROS
+
 extern "C" {
 #endif
 
@@ -24,7 +27,7 @@ extern "C" {
 #include "lexbor/core/lexbor.h"
 
 #define LEXBOR_VERSION_MAJOR 1
-#define LEXBOR_VERSION_MINOR 4
+#define LEXBOR_VERSION_MINOR 6
 #define LEXBOR_VERSION_PATCH 0
 
 #define LEXBOR_VERSION_STRING LEXBOR_STRINGIZE(LEXBOR_VERSION_MAJOR) "."       \
@@ -77,6 +80,15 @@ lexbor_action_t;
 typedef lxb_status_t
 (*lexbor_serialize_cb_f)(const lxb_char_t *data, size_t len, void *ctx);
 
+typedef struct {
+    lexbor_serialize_cb_f cb;
+    void                  *ctx;
+
+    intptr_t              opt;
+    size_t                count;
+}
+lexbor_serialize_ctx_t;
+
 
 #ifdef __cplusplus
 } /* extern "C" */
