@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2018 Alexander Borisov
+ * Copyright (C) 2018-2021 Alexander Borisov
  *
  * Author: Alexander Borisov <borisov@lexbor.com>
  */
@@ -12,6 +12,7 @@ extern "C" {
 #endif
 
 #include "lexbor/dom/interface.h"
+#include "lexbor/dom/collection.h"
 #include "lexbor/dom/interfaces/event_target.h"
 
 
@@ -66,27 +67,50 @@ struct lxb_dom_node {
 LXB_API lxb_dom_node_t *
 lxb_dom_node_interface_create(lxb_dom_document_t *document);
 
+LXB_API lxb_dom_node_t *
+lxb_dom_node_interface_clone(lxb_dom_document_t *document,
+                             const lxb_dom_node_t *node, bool is_attr);
+
 LXB_API lxb_dom_node_t *
 lxb_dom_node_interface_destroy(lxb_dom_node_t *node);
 
+LXB_API lxb_status_t
+lxb_dom_node_interface_copy(lxb_dom_node_t *dst,
+                            const lxb_dom_node_t *src, bool is_attr);
+
 LXB_API lxb_dom_node_t *
 lxb_dom_node_destroy(lxb_dom_node_t *node);
 
 LXB_API lxb_dom_node_t *
 lxb_dom_node_destroy_deep(lxb_dom_node_t *root);
 
+LXB_API lxb_dom_node_t *
+lxb_dom_node_clone(lxb_dom_node_t *node, bool deep);
+
 LXB_API const lxb_char_t *
 lxb_dom_node_name(lxb_dom_node_t *node, size_t *len);
 
+LXB_API void
+lxb_dom_node_insert_child_wo_events(lxb_dom_node_t *to, lxb_dom_node_t *node);
+
 LXB_API void
 lxb_dom_node_insert_child(lxb_dom_node_t *to, lxb_dom_node_t *node);
 
+LXB_API void
+lxb_dom_node_insert_before_wo_events(lxb_dom_node_t *to, lxb_dom_node_t *node);
+
 LXB_API void
 lxb_dom_node_insert_before(lxb_dom_node_t *to, lxb_dom_node_t *node);
 
+LXB_API void
+lxb_dom_node_insert_after_wo_events(lxb_dom_node_t *to, lxb_dom_node_t *node);
+
 LXB_API void
 lxb_dom_node_insert_after(lxb_dom_node_t *to, lxb_dom_node_t *node);
 
+LXB_API void
+lxb_dom_node_remove_wo_events(lxb_dom_node_t *node);
+
 LXB_API void
 lxb_dom_node_remove(lxb_dom_node_t *node);
 
@@ -97,6 +121,36 @@ LXB_API void
 lxb_dom_node_simple_walk(lxb_dom_node_t *root,
                          lxb_dom_node_simple_walker_f walker_cb, void *ctx);
 
+LXB_API lxb_status_t
+lxb_dom_node_by_tag_name(lxb_dom_node_t *root, lxb_dom_collection_t *collection,
+                         const lxb_char_t *qualified_name, size_t len);
+LXB_API lxb_status_t
+lxb_dom_node_by_class_name(lxb_dom_node_t *root,
+                           lxb_dom_collection_t *collection,
+                           const lxb_char_t *class_name, size_t len);
+LXB_API lxb_status_t
+lxb_dom_node_by_attr(lxb_dom_node_t *root, lxb_dom_collection_t *collection,
+                     const lxb_char_t *qualified_name, size_t qname_len,
+                     const lxb_char_t *value, size_t value_len,
+                     bool case_insensitive);
+LXB_API lxb_status_t
+lxb_dom_node_by_attr_begin(lxb_dom_node_t *root,
+                           lxb_dom_collection_t *collection,
+                           const lxb_char_t *qualified_name, size_t qname_len,
+                           const lxb_char_t *value, size_t value_len,
+                           bool case_insensitive);
+LXB_API lxb_status_t
+lxb_dom_node_by_attr_end(lxb_dom_node_t *root, lxb_dom_collection_t *collection,
+                         const lxb_char_t *qualified_name, size_t qname_len,
+                         const lxb_char_t *value, size_t value_len,
+                         bool case_insensitive);
+LXB_API lxb_status_t
+lxb_dom_node_by_attr_contain(lxb_dom_node_t *root,
+                             lxb_dom_collection_t *collection,
+                             const lxb_char_t *qualified_name, size_t qname_len,
+                             const lxb_char_t *value, size_t value_len,
+                             bool case_insensitive);
+
 /*
  * Memory of returns value will be freed in document destroy moment.
  * If you need to release returned resource after use, then call the
@@ -155,22 +209,22 @@ lxb_dom_node_last_child(lxb_dom_node_t *node)
 /*
  * No inline functions for ABI.
  */
-lxb_tag_id_t
+LXB_API lxb_tag_id_t
 lxb_dom_node_tag_id_noi(lxb_dom_node_t *node);
 
-lxb_dom_node_t *
+LXB_API lxb_dom_node_t *
 lxb_dom_node_next_noi(lxb_dom_node_t *node);
 
-lxb_dom_node_t *
+LXB_API lxb_dom_node_t *
 lxb_dom_node_prev_noi(lxb_dom_node_t *node);
 
-lxb_dom_node_t *
+LXB_API lxb_dom_node_t *
 lxb_dom_node_parent_noi(lxb_dom_node_t *node);
 
-lxb_dom_node_t *
+LXB_API lxb_dom_node_t *
 lxb_dom_node_first_child_noi(lxb_dom_node_t *node);
 
-lxb_dom_node_t *
+LXB_API lxb_dom_node_t *
 lxb_dom_node_last_child_noi(lxb_dom_node_t *node);
 
 
