@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2018-2020 Alexander Borisov
+ * Copyright (C) 2018-2021 Alexander Borisov
  *
  * Author: Alexander Borisov <borisov@lexbor.com>
  */
@@ -210,7 +210,8 @@ lxb_html_parse_fragment_chunk_begin(lxb_html_parser_t *parser,
         goto done;
     }
 
-    lxb_dom_node_insert_child(lxb_dom_interface_node(new_doc), parser->root);
+    lxb_dom_node_insert_child_wo_events(lxb_dom_interface_node(new_doc),
+                                        parser->root);
     lxb_dom_document_attach_element(doc, lxb_dom_interface_element(parser->root));
 
     parser->tree->fragment = lxb_html_interface_create(new_doc, tag_id, ns);
@@ -455,3 +456,15 @@ lxb_html_parser_state_noi(lxb_html_parser_t *parser)
 {
     return lxb_html_parser_state(parser);
 }
+
+bool
+lxb_html_parser_scripting_noi(lxb_html_parser_t *parser)
+{
+    return lxb_html_parser_scripting(parser);
+}
+
+void
+lxb_html_parser_scripting_set_noi(lxb_html_parser_t *parser, bool scripting)
+{
+    lxb_html_parser_scripting_set(parser, scripting);
+}
